Clazz.declarePackage("J.api.js");
Clazz.declareInterface(J.api.js, "GenericConsoleTextArea");
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
